@@ -44,7 +44,7 @@ typedef struct {
 /* Destructor of BibtexFile */
 static void bibtex_py_close (PyBibtexSource_Object * self) {
     bibtex_source_destroy (self->obj, TRUE);
-    PyMem_DEL (self);
+    PyObject_DEL (self);
 }
 
 /* Destructor of BibtexEntry */
@@ -53,7 +53,7 @@ static void destroy_field (PyBibtexField_Object * self)
 {
     bibtex_field_destroy (self->obj, TRUE);
 
-    PyMem_DEL (self);
+    PyObject_DEL (self);
 }
 
 static char PyBibtexSource_Type__doc__[] = "This is the type of a BibTeX source";
@@ -200,7 +200,7 @@ bib_expand (PyObject * self, PyObject * args) {
 	    field->type = type;
 	}
 
-	bibtex_field_parse (field, file->table);
+	bibtex_field_parse(field, file->table);
     }
 
     switch (field->type) {
@@ -610,11 +610,11 @@ bib_reverse (PyObject * self, PyObject * args)
 	return NULL;
     }
 
-    quote = 0;
+    quote = 1;
 
     switch (field->type) {
     case BIBTEX_VERBATIM:
-	quote = 1;
+	quote = 0;
 
     case BIBTEX_OTHER:
     case BIBTEX_TITLE:
